import { Link } from 'react-router-dom';
import { ArrowRight, Code, BookOpen, Github, ExternalLink } from 'lucide-react';
import { motion } from 'framer-motion';
import { trackOutboundLink } from '../components/Analytics';

// Mock data - will be replaced with actual data later
const stats = [
  { label: 'Projects Completed', value: '5+' },
  { label: 'Blog Posts Written', value: '15+' },
  { label: 'Technologies Mastered', value: '15+' },
  { label: 'Developers Helped', value: '100+' },
];

const featuredProjects = [
  {
    id: '1',
    title: 'Odyssey: Business Tourism Web App',
    description: 'Odyssey is a modern tourism web application designed as a college project to help users explore, plan, and navigate tourist destinations with real-time directions and a beautiful, responsive interface. Built with a robust tech stack and deployed on Azure, Odyssey delivers a seamless and interactive experience for travelers.',
    technologies: ['React', 'Node.js', 'Leaflet & OpenStreetMap ', 'GitHub Actions (CI/CD)', 'Azure', 'shadcn-ui', 'Tailwind CSS', 'Framer Motion'],
    liveUrl: 'https://witty-island-086886500.6.azurestaticapps.net/',
    githubUrl: 'https://github.com/MohitSutharOfficial/Odyssey-Tourism',
  },
  {
    id: '2',
    title: 'OwnMap: Interactive Map Application',
    description: 'This is a professional web-based mapping application that allows users to visualize locations, find their current position, search for places, and calculate distances between points. The application provides both straight-line distance calculations and actual road distance routing with estimated travel times.',
    technologies: ['HTML5', 'CSS3', ' JavaScript', ' Leaflet.js', 'OpenStreetMap', 'Geolocation API', 'Distance Calculation Algorithms'],
    liveUrl: 'https://mohitsutharofficial.github.io/Own-google-mapapp/',
    githubUrl: 'https://github.com/MohitSutharOfficial/Own-google-mapapp',
  },
];

export default function Home() {
  return (
    <div className="min-h-screen">      {/* Hero Section */}
      <section className="relative overflow-hidden bg-gradient-to-br from-primary-50 via-white to-secondary-50 dark:from-gray-900 dark:via-gray-800 dark:to-gray-900">
        <div className="absolute inset-0 bg-grid-pattern opacity-5 dark:opacity-10"></div>
        <div className="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-20 lg:py-32">
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
            {/* Hero Content */}
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.6 }}
              className="text-center lg:text-left"
            >
              <motion.div
                initial={{ opacity: 0, scale: 0.8 }}
                animate={{ opacity: 1, scale: 1 }}
                transition={{ duration: 0.6, delay: 0.2 }}
                className="inline-flex items-center px-4 py-2 rounded-full bg-primary-100 dark:bg-primary-900/40 text-primary-700 dark:text-primary-300 text-sm font-medium mb-6 border border-primary-200 dark:border-primary-800"
              >
                <span className="w-2 h-2 bg-green-500 rounded-full mr-2 animate-pulse" />
                Available for new opportunities
              </motion.div>

              <h1 className="text-3xl sm:text-4xl lg:text-5xl font-heading font-bold text-gray-900 dark:text-white leading-tight mb-6">
                Hi, I'm{' '}
                <span className="gradient-text">Mohit Suthar</span>
              </h1>

              <h2 className="text-lg sm:text-xl lg:text-2xl font-heading font-semibold text-gray-700 dark:text-gray-300 mb-6">
                Full-Stack Developer & Tech Educator
              </h2>

              <p className="text-professional text-gray-600 dark:text-gray-400 mb-8 max-w-2xl">
                I create amazing web experiences and help developers grow their careers through
                comprehensive tutorials, hands-on projects, and mentoring.
              </p>

              {/* CTA Buttons */}
              <div className="flex flex-col sm:flex-row gap-4 mb-12">
                <Link to="/projects" className="btn-primary group inline-flex items-center justify-center">
                  View My Projects
                  <ArrowRight size={20} className="ml-2 group-hover:translate-x-1 transition-transform duration-200" />
                </Link>
                <Link to="/learning" className="btn-outline group inline-flex items-center justify-center">
                  <BookOpen size={20} className="mr-2 group-hover:rotate-12 transition-transform duration-200" />
                  Start Learning
                </Link>
                <Link to="/blog" className="btn-secondary group inline-flex items-center justify-center">
                  <Code size={20} className="mr-2 group-hover:scale-110 transition-transform duration-200" />
                  Read Blog
                </Link>
              </div>

              {/* Stats */}
              <div className="grid grid-cols-2 lg:grid-cols-4 gap-6">
                {stats.map((stat, index) => (
                  <motion.div
                    key={stat.label}
                    initial={{ opacity: 0, y: 20 }}
                    animate={{ opacity: 1, y: 0 }}
                    transition={{ duration: 0.6, delay: 0.4 + index * 0.1 }}
                    className="text-center group cursor-pointer"
                  >
                    <div className="text-2xl lg:text-3xl font-bold text-primary-600 dark:text-primary-400 mb-1 group-hover:scale-110 transition-transform duration-200">
                      {stat.value}
                    </div>
                    <div className="text-sm text-gray-600 dark:text-gray-400 group-hover:text-gray-900 dark:group-hover:text-gray-200 transition-colors duration-200">
                      {stat.label}
                    </div>
                  </motion.div>
                ))}
              </div>
            </motion.div>

            {/* Hero Image/Animation */}
            <motion.div
              initial={{ opacity: 0, x: 20 }}
              animate={{ opacity: 1, x: 0 }}
              transition={{ duration: 0.6, delay: 0.3 }}
              className="relative"
            >
              <div className="relative z-10 bg-gradient-to-br from-primary-500 to-secondary-500 rounded-2xl p-8 shadow-2xl hover:shadow-3xl transition-all duration-300 transform hover:scale-105">
                <div className="bg-white/10 backdrop-blur-lg rounded-lg p-6 text-white">
                  <div className="flex items-center mb-4">
                    <div className="w-3 h-3 bg-red-400 rounded-full mr-2" />
                    <div className="w-3 h-3 bg-yellow-400 rounded-full mr-2" />
                    <div className="w-3 h-3 bg-green-400 rounded-full mr-2" />
                    <span className="text-sm opacity-75">portfolio.tsx</span>
                  </div>
                  <div className="font-mono text-sm leading-relaxed">
                    <div className="text-blue-200">const</div>{' '}
                    <div className="text-yellow-200">developer</div>{' '}
                    <div className="text-white">=</div>{' '}
                    <div className="text-white">{'{'}</div>
                    <div className="ml-4">
                      <div className="text-blue-200">name:</div>{' '}
                      <div className="text-green-200">'Mohit Suthar'</div>
                      <div className="text-white">,</div>
                    </div>
                    <div className="ml-4">
                      <div className="text-blue-200">skills:</div>{' '}
                      <div className="text-white">['React', 'Node.js', 'Python']</div>
                      <div className="text-white">,</div>
                    </div>
                    <div className="ml-4">
                      <div className="text-blue-200">passion:</div>{' '}
                      <div className="text-green-200">'Teaching & Building'</div>
                    </div>
                    <div className="text-white">{'}'}</div>
                  </div>
                </div>
              </div>
              <div className="absolute -top-4 -right-4 w-72 h-72 bg-gradient-to-r from-primary-400 to-secondary-400 rounded-full blur-3xl opacity-20 dark:opacity-30 animate-pulse"></div>
            </motion.div>
          </div>
        </div>
      </section>      {/* Featured Projects Section */}
      <section className="py-20 bg-white dark:bg-gray-800 relative">
        <div className="absolute inset-0 bg-gradient-to-b from-transparent to-gray-50 dark:to-gray-900/50 pointer-events-none"></div>
        <div className="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <h2 className="text-3xl lg:text-4xl font-heading font-bold text-gray-900 dark:text-white mb-4">
              Featured Projects
            </h2>
            <p className="text-xl text-gray-600 dark:text-gray-400 max-w-3xl mx-auto">
              A showcase of my recent work, demonstrating technical expertise and problem-solving abilities.
            </p>
          </div>

          <div className="grid grid-cols-1 lg:grid-cols-2 gap-8 mb-12">
            {featuredProjects.map((project, index) => (
              <motion.div
                key={project.id}
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.6, delay: index * 0.1 }}
                className="bg-gray-50 dark:bg-gray-700 rounded-2xl overflow-hidden shadow-lg hover:shadow-2xl transition-all duration-300 transform hover:scale-105 hover:-translate-y-2 group border border-gray-200 dark:border-gray-600"
              >
                <div className="aspect-video bg-gradient-to-br from-primary-400 to-secondary-400 relative overflow-hidden">
                  <div className="absolute inset-0 bg-black/20 flex items-center justify-center group-hover:bg-black/10 transition-colors duration-300">
                    <Code size={40} className="text-white group-hover:scale-110 transition-transform duration-300" />
                  </div>
                  <div className="absolute top-4 right-4 opacity-0 group-hover:opacity-100 transition-opacity duration-300">
                    <div className="bg-white/20 backdrop-blur-sm rounded-full p-2">
                      <ArrowRight size={16} className="text-white" />
                    </div>
                  </div>
                </div>

                <div className="p-6">
                  <h3 className="font-heading font-semibold text-xl text-gray-900 dark:text-white mb-3 group-hover:text-primary-600 dark:group-hover:text-primary-400 transition-colors duration-200">
                    {project.title}
                  </h3>
                  <p className="text-gray-600 dark:text-gray-400 mb-4">
                    {project.description}
                  </p>

                  <div className="flex flex-wrap gap-2 mb-4">
                    {project.technologies.map((tech) => (
                      <span
                        key={tech}
                        className="px-3 py-1 bg-primary-100 dark:bg-primary-900/40 text-primary-700 dark:text-primary-300 text-sm rounded-full font-medium hover:bg-primary-200 dark:hover:bg-primary-900/60 transition-colors duration-200 cursor-default"
                      >
                        {tech}
                      </span>
                    ))}
                  </div>
                  <div className="flex gap-3">
                    <a
                      href={project.liveUrl}
                      onClick={() => trackOutboundLink(project.liveUrl)}
                      className="flex-1 bg-primary-600 hover:bg-primary-700 text-white font-medium py-2.5 px-4 rounded-lg transition-all duration-200 focus:outline-none focus:ring-2 focus:ring-primary-500 focus:ring-offset-2 dark:focus:ring-offset-gray-700 text-center inline-flex items-center justify-center group"
                    >
                      <ExternalLink size={16} className="mr-2 group-hover:rotate-12 transition-transform duration-200" />
                      Live Demo
                    </a>
                    <a
                      href={project.githubUrl}
                      onClick={() => trackOutboundLink(project.githubUrl)}
                      className="flex-1 border-2 border-primary-600 text-primary-600 hover:bg-primary-600 hover:text-white dark:border-primary-400 dark:text-primary-400 dark:hover:bg-primary-400 dark:hover:text-gray-900 font-medium py-2.5 px-4 rounded-lg transition-all duration-200 focus:outline-none focus:ring-2 focus:ring-primary-500 focus:ring-offset-2 dark:focus:ring-offset-gray-700 text-center inline-flex items-center justify-center group"
                    >
                      <Github size={16} className="mr-2 group-hover:scale-110 transition-transform duration-200" />
                      Code
                    </a>
                  </div>
                </div>
              </motion.div>
            ))}
          </div>

          <div className="text-center">
            <Link to="/projects" className="btn-outline group inline-flex items-center">
              View All Projects
              <ArrowRight size={20} className="ml-2 group-hover:translate-x-1 transition-transform duration-200" />
            </Link>
          </div>
        </div>
      </section>      {/* Call-to-Action Section */}
      <section className="py-20 bg-gradient-to-r from-primary-600 via-primary-700 to-secondary-600 relative overflow-hidden">
        <div className="absolute inset-0 bg-black/10"></div>
        <div className="absolute top-0 left-1/4 w-96 h-96 bg-white/10 rounded-full blur-3xl animate-pulse"></div>
        <div className="absolute bottom-0 right-1/4 w-96 h-96 bg-secondary-400/20 rounded-full blur-3xl animate-pulse delay-1000"></div>
        <div className="relative max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <h2 className="text-3xl lg:text-4xl font-heading font-bold text-white mb-6">
            Let's Build Something Amazing Together
          </h2>
          <p className="text-xl text-primary-100 mb-8">
            Whether you're looking for collaboration, mentorship, or just want to chat about technology,
            I'm always excited to connect with fellow developers and innovators.
          </p>
          <div className="flex flex-col sm:flex-row gap-4 justify-center">
            <Link to="/contact" className="bg-white text-primary-600 hover:bg-gray-100 hover:scale-105 focus:scale-105 font-medium py-3 px-8 rounded-lg transition-all duration-200 inline-flex items-center justify-center group shadow-lg hover:shadow-xl">
              Get In Touch
              <ArrowRight size={20} className="ml-2 group-hover:translate-x-1 transition-transform duration-200" />
            </Link>
            <Link to="/projects" className="border-2 border-white text-white hover:bg-white hover:text-primary-600 hover:scale-105 focus:scale-105 font-medium py-3 px-8 rounded-lg transition-all duration-200 inline-flex items-center justify-center group shadow-lg hover:shadow-xl">
              View My Work
              <Code size={20} className="ml-2 group-hover:rotate-12 transition-transform duration-200" />
            </Link>
          </div>
        </div>
      </section>
    </div>
  );
}
